# Changelog

## 1.0.0 (unreleased)

Initial release.


..
  <!--
  All notable changes to this project will be documented in this file.

  The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
  and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

  ## [Unreleased]
  ### Added
  ### Changed
  ### Deprecated
  ### Removed
  ### Fixed
  ### Security
  First release
  ## 0.1.0 (2020-03-01)
  ### Added
  for new features.
  ### Changed
  for changes in existing functionality.
  ### Deprecated
  for soon-to-be removed features.
  ### Removed
  for now removed features.
  ### Fixed
  for any bug fixes.
  ### Security
  in case of vulnerabilities.
  -->
